@@ -28,8 +28,6 @@ function Button(widget, buttonColor, pressedButtonColor, textColor, font) {
 
 Button.prototype = {
     _init : function(widgetOrText, buttonColor, pressedButtonColor, textColor, font) {
-        let me = this;
-
         this._buttonColor = buttonColor
         if (buttonColor == null)
             this._buttonColor = DEFAULT_BUTTON_COLOR;
@@ -108,16 +106,15 @@ iconButton.prototype = {
         this.actor.set_opacity(0);
         parent.connect("enter-event", Lang.bind(this, function(actor, event) {
             this._shouldHide = false;
-
             // Nothing to do if the cursor has come back from a child of the parent actor
-            if (actor.get_children().indexOf(Shell.get_event_related(event)) != -1)
+            if (actor.get_children().indexOf(event.get_related()) != -1)
                 return;
 
             this._fadeIn();
         }));
         parent.connect("leave-event", Lang.bind(this, function(actor, event) {
             // Nothing to do if the cursor has merely entered a child of the parent actor
-            if (actor.get_children().indexOf(Shell.get_event_related(event)) != -1)
+            if (actor.get_children().indexOf(event.get_related()) != -1)
                 return;
 
             // Remember that we should not be visible to hide the button if forceShow is unset
