@@ -345,7 +345,7 @@ window_is_tracked (MetaWindow *window)
 }
 
 /**
- * window_is_usage_tracked:
+ * shell_app_monitor_is_window_usage_tracked:
  *
  * Determine if it makes sense to track the given window for application
  * usage.  An example of a window we don't want to track is the root
@@ -358,12 +358,15 @@ window_is_tracked (MetaWindow *window)
  *
  * Returns: %TRUE iff we want to record focus time spent in this window
  */
-static gboolean
-window_is_usage_tracked (MetaWindow *window)
+gboolean
+shell_app_monitor_is_window_usage_tracked (MetaWindow *window)
 {
   if (!window_is_tracked (window))
     return FALSE;
 
+  if (meta_window_is_skip_taskbar (window))
+    return FALSE;
+
   switch (meta_window_get_window_type (window))
     {
       /* Definitely ignore these. */
@@ -434,9 +437,10 @@ get_app_for_window_direct (MetaWindow  *window)
 
       if (id != NULL)
         result = shell_app_system_load_from_desktop_file (appsys, id, NULL);
-      else
-        result = create_transient_app_for_window (window);
     }
+  if (result == NULL)
+    result = create_transient_app_for_window (window);
+
   return result;
 }
 
@@ -562,7 +566,7 @@ get_active_window (ShellAppMonitor *monitor)
   display = meta_screen_get_display (screen);
   window = meta_display_get_focus_window (display);
 
-  if (window != NULL && window_is_usage_tracked (window))
+  if (window != NULL && shell_app_monitor_is_window_usage_tracked (window))
     return window;
   return NULL;
 }
@@ -756,7 +760,7 @@ track_window (ShellAppMonitor *self,
    * tracked it doesn't count for the purposes of an application
    * running.
    */
-  if (!window_is_usage_tracked (window))
+  if (!shell_app_monitor_is_window_usage_tracked (window))
     return;
 
   usage = get_app_usage_from_window (self, window);
@@ -812,7 +816,7 @@ disassociate_window (ShellAppMonitor   *self,
   if (window == self->watched_window)
     self->watched_window = NULL;
 
-  if (window_is_usage_tracked (window))
+  if (shell_app_monitor_is_window_usage_tracked (window))
     {
       AppUsage *usage;
       const char *context;
@@ -930,7 +934,7 @@ shell_app_monitor_get_windows_for_app (ShellAppMonitor *self,
       ShellAppInfo *app = value;
       const char *id = shell_app_info_get_id (app);
 
-      if (!window_is_usage_tracked (window))
+      if (!shell_app_monitor_is_window_usage_tracked (window))
         continue;
 
       if (strcmp (id, appid) != 0)
@@ -1181,7 +1185,7 @@ shell_app_monitor_get_running_apps (ShellAppMonitor *monitor,
       if (strcmp (get_window_context (window), context) != 0)
         continue;
 
-      if (!window_is_usage_tracked (window))
+      if (!shell_app_monitor_is_window_usage_tracked (window))
         continue;
 
       id = shell_app_info_get_id (app);
