@@ -13,17 +13,14 @@ ClutterCairoTexture *shell_create_vertical_gradient (ClutterColor *top,
 ClutterCairoTexture *shell_create_horizontal_gradient (ClutterColor *left,
                                                        ClutterColor *right);
 
+void shell_draw_box_pointer (ClutterCairoTexture *texture,
+                             ClutterColor        *border_color,
+                             ClutterColor        *background_color);
+
 void shell_draw_clock (ClutterCairoTexture *texture,
 	               int                  hour,
 	               int                  minute);
 
-void shell_draw_app_highlight (ClutterCairoTexture *texture,
-                               int                  num_windows,
-                               double               red,
-                               double               blue,
-                               double               green,
-                               double               alpha);
-
 guint shell_add_hook_paint_red_border (ClutterActor *actor);
 
 G_END_DECLS
